==> qt-creator-opensource-src-3.5.1.tar.gz: qt-creator-opensource-src-3.5.1/src/libs/clangbackendipc/ipcclientdispatcher.cpp <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "ipcclientdispatcher.h"

#include <QDebug>

namespace ClangBackEnd {

void IpcClientDispatcher::addClient(IpcClientInterface *client)
{
    clients.append(client);
}

void IpcClientDispatcher::removeClient(IpcClientInterface *client)
{
    clients.removeOne(client);
}

void IpcClientDispatcher::alive()
{
    for (auto *client : clients)
        client->alive();
}

void IpcClientDispatcher::echo(const EchoCommand &command)
{
    for (auto *client : clients)
        client->echo(command);
}

void IpcClientDispatcher::codeCompleted(const CodeCompletedCommand &command)
{
    for (auto *client : clients)
        client->codeCompleted(command);
}

void IpcClientDispatcher::translationUnitDoesNotExist(const TranslationUnitDoesNotExistCommand &command)
{
    for (auto *client : clients)
        client->translationUnitDoesNotExist(command);
}

void IpcClientDispatcher::projectPartsDoNotExist(const ProjectPartsDoNotExistCommand &command)
{
    for (auto *client : clients)
        client->projectPartsDoNotExist(command);
}

} // namespace ClangBackEnd

==> qt-creator-opensource-src-3.6.1.tar.gz: qt-creator-opensource-src-3.6.1/src/libs/clangbackendipc/ipcclientdispatcher.cpp <==
/****************************************************************************
**
** Copyright (C) 2015 The Qt Company Ltd.
** Contact: http://www.qt.io/licensing
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://www.qt.io/licensing.  For further information
** use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file.  Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
****************************************************************************/

#include "ipcclientdispatcher.h"

#include <QDebug>

namespace ClangBackEnd {

void IpcClientDispatcher::addClient(IpcClientInterface *client)
{
    clients.append(client);
}

void IpcClientDispatcher::removeClient(IpcClientInterface *client)
{
    clients.removeOne(client);
}

void IpcClientDispatcher::alive()
{
    for (auto *client : clients)
        client->alive();
}

void IpcClientDispatcher::echo(const EchoMessage &message)
{
    for (auto *client : clients)
        client->echo(message);
}

void IpcClientDispatcher::codeCompleted(const CodeCompletedMessage &message)
{
    for (auto *client : clients)
        client->codeCompleted(message);
}

void IpcClientDispatcher::translationUnitDoesNotExist(const TranslationUnitDoesNotExistMessage &message)
{
    for (auto *client : clients)
        client->translationUnitDoesNotExist(message);
}

void IpcClientDispatcher::projectPartsDoNotExist(const ProjectPartsDoNotExistMessage &message)
{
    for (auto *client : clients)
        client->projectPartsDoNotExist(message);
}

void IpcClientDispatcher::diagnosticsChanged(const DiagnosticsChangedMessage &message)
{
    for (auto *client : clients)
        client->diagnosticsChanged(message);
}

void IpcClientDispatcher::highlightingChanged(const HighlightingChangedMessage &message)
{
    for (auto *client : clients)
        client->highlightingChanged(message);
}

} // namespace ClangBackEnd
